# ApiListPipelineVersionsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**versions** | [**list[ApiPipelineVersion]**](ApiPipelineVersion.md) |  | [optional] 
**next_page_token** | **str** | The token to list the next page of pipeline versions. | [optional] 
**total_size** | **int** | The total number of pipeline versions for the given query. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


